@@ -10,8 +10,19 @@
 # ruff: noqa: E402 - Module level import not at top of file
 # ruff: noqa: F401 - `var` imported but unused
 
+import platform
 from enum import Enum
 
+# Do the platform check once at module level
+IS_WASM = platform.machine() == "wasm32"
+# IS_WASM = True  # for testing (comment this line out for production)
+"""
+Flag for WebAssembly platform.
+"""
+
+if not IS_WASM:
+    import numexpr
+
 from .version import __version__
 
 __version__ = __version__
@@ -96,6 +107,7 @@ from .blosc2_ext import (
     DEFINED_CODECS_STOP,
     EXTENDED_HEADER_LENGTH,
     GLOBAL_REGISTERED_CODECS_STOP,
+    MAX_BLOCKSIZE,
     MAX_BUFFERSIZE,
     MAX_OVERHEAD,
     MAX_TYPESIZE,
@@ -193,9 +205,13 @@ nthreads = ncores = cpu_info.get("count", 1)
 """Number of threads to be used in compression/decompression.
 """
 # Protection against too many threads
-nthreads = min(nthreads, 32)
+nthreads = min(nthreads, 64)
 # Experiments say that, when using a large number of threads, it is better to not use them all
-nthreads -= nthreads // 8
+if nthreads > 16:
+    nthreads -= nthreads // 8
+if not IS_WASM:
+    # WASM does not support threading
+    numexpr.set_num_threads(nthreads)
 
 # This import must be before ndarray and schunk
 from .storage import (  # noqa: I001
@@ -231,6 +247,10 @@ from .ndarray import (
     ones,
     full,
     save,
+    matmul,
+    permute_dims,
+    transpose,
+    matrix_transpose,
 )
 
 from .c2array import c2context, C2Array, URLPath
@@ -243,12 +263,12 @@ from .lazyexpr import (
     _open_lazyarray,
     get_expr_operands,
     validate_expr,
+    evaluate,
 )
-from .proxy import Proxy, ProxySource, ProxyNDSource, ProxyNDField
+from .proxy import Proxy, ProxySource, ProxyNDSource, ProxyNDField, SimpleProxy, jit
 
 from .schunk import SChunk, open
 
-
 # Registry for postfilters
 postfilter_funcs = {}
 """
